Jmbo Skeleton Readme
====================

Create a Jmbo project environment quickly. Includes a Jmbo demo application. 

Demo
----

From the terminal::

 ./demo.sh


Jmbo project environment
------------------------

From the terminal::

 ./scripts/create-jmbo-project.sh

